@@ -5,10 +5,18 @@ from pydantic import BaseModel
 from nonebot import get_driver, get_bot
 from nonebot.log import logger
 from nonebot.drivers import ReverseDriver
+from nonebot.plugin import PluginMetadata
 
 from .config import Config
 
 
+__plugin_meta__ = PluginMetadata(
+    name='推送钩子',
+    description='实现消息推送自由',
+    usage='详见项目 README.md'
+)
+
+
 driver = get_driver()
 config = Config.parse_obj(driver.config)
 
@@ -21,34 +29,47 @@ class Report(BaseModel):
     title: Optional[str] = None
     content: str
     send_to: Optional[Union[str, List[str]]] = None
+    send_to_group: Optional[Union[str, List[str]]] = None
 
 
 app = FastAPI()
 
-@app.post('/', status_code=200)
+@app.post(config.report_route, status_code=200)
 async def push(r: Report):
     if config.report_token is not None \
     and r.token != config.report_token:
         raise HTTPException(status.HTTP_403_FORBIDDEN)
 
-    r.title = r.title or ''
-
-    msg = f'[report] {r.title}\n{r.content}'
-    if r.send_to is None:
-        send_to = config.superusers
-    elif isinstance(r.send_to, str):
-        send_to = [r.send_to]
-    else:
-        send_to = r.send_to
-
+    msg = config.report_template.format(
+        title=r.title or '',
+        content=r.content
+    )
     bot = get_bot()
-    for id in send_to:
-        await bot.send_msg(user_id=id, message=msg)
+
+    if isinstance(r.send_to, str):
+        uids = [r.send_to]
+    elif isinstance(r.send_to, list):
+        uids = r.send_to
+    else:
+        uids = config.superusers
+
+    for uid in uids:
+        await bot.send_msg(user_id=uid, message=msg)
+
+    if isinstance(r.send_to_group, str):
+        gids = [r.send_to_group]
+    elif isinstance(r.send_to_group, list):
+        gids = r.send_to_group
+    else:
+        gids = []
+
+    for gid in gids:
+        await bot.send_msg(group_id=gid, message=msg)
 
     logger.info(
         'Report pushed:'
         f' title={repr(r.title)},'
-        f' message={repr(r.content)},'
+        f' content={repr(r.content)},'
         f' send_to={repr(r.send_to)}'
     )
 
@@ -58,5 +79,5 @@ async def startup():
     if not config.report_token and config.environment == 'prod':
         logger.warning('You are in production environment without setting a token, everyone can access your webhook')
 
-    driver.server_app.mount(config.report_route, app)
+    driver.server_app.mount('/', app)
     logger.info(f'Mounted to {config.report_route}')
